#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-2lqExlJK3kpBEBgaYbkwZV
key:                  http-streams-0.8.9.9-2lqExlJK3kpBEBgaYbkwZV
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  133724fefc83e46b4da3334c5afdebd3
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-2lqExlJK3kpBEBgaYbkwZV
depends:
    HsOpenSSL-0.11.7.9-I6voCd3ZZTix18QaGWFSc
    aeson-2.2.2.0-I4TBg1DJhLsFbcwgkuafNJ
    attoparsec-0.14.4-XKrSjVngnD4c93iEpE5SP
    attoparsec-aeson-2.2.0.1-Jp0SqJFiJfdKkOJhGNSwcD base-4.18.2.1
    base64-bytestring-1.2.1.0-HTSPucLWQY58n8fXtuig9
    blaze-builder-0.4.4.1-D2h3Qn3VgsyIHA3dmM49cD bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Io2qVGlYpC0Ko64AoDztcG directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-FTcACS9Cuy52e2ZHRub7qy
    io-streams-1.5.2.2-Bglbj5McRDb8lopaclRdWI mtl-2.3.1
    network-3.1.4.0-3TdAlJZpcec7X0sHQ887x8
    network-uri-2.6.4.2-CG8j03sAL8xAn9DHaXlCLv
    openssl-streams-1.2.3.0-43jIZt6BbKl2vekAAL1wH7 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

